Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev Fix typo, pointed out by Markus W Kilbinger



details:   https://anonhg.NetBSD.org/src/rev/f3e05bb1956a
branches:  trunk
changeset: 781114:f3e05bb1956a
user:      bouyer <bouyer%NetBSD.org@localhost>
date:      Mon Aug 20 12:48:47 2012 +0000

description:
Fix typo, pointed out by Markus W Kilbinger

diffstat:

 sys/dev/ic/ahcisata_core.c |   8 ++++----
 sys/dev/ic/ahcisatavar.h   |   4 ++--
 sys/dev/pci/ahcisata_pci.c |  10 +++++-----
 3 files changed, 11 insertions(+), 11 deletions(-)

diffs (95 lines):

diff -r 0b178cb5d68a -r f3e05bb1956a sys/dev/ic/ahcisata_core.c
--- a/sys/dev/ic/ahcisata_core.c        Mon Aug 20 12:45:36 2012 +0000
+++ b/sys/dev/ic/ahcisata_core.c        Mon Aug 20 12:48:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ahcisata_core.c,v 1.42 2012/08/20 11:59:29 bouyer Exp $        */
+/*     $NetBSD: ahcisata_core.c,v 1.43 2012/08/20 12:48:47 bouyer Exp $        */
 
 /*
  * Copyright (c) 2006 Manuel Bouyer.
@@ -26,7 +26,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ahcisata_core.c,v 1.42 2012/08/20 11:59:29 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ahcisata_core.c,v 1.43 2012/08/20 12:48:47 bouyer Exp $");
 
 #include <sys/types.h>
 #include <sys/malloc.h>
@@ -225,7 +225,7 @@
                return;
 
        sc->sc_ahci_cap = AHCI_READ(sc, AHCI_CAP);
-       if (sc->sc_achi_quirks & AHCI_QUIRK_BADPMP) {
+       if (sc->sc_ahci_quirks & AHCI_QUIRK_BADPMP) {
                aprint_verbose_dev(sc->sc_atac.atac_dev,
                    "ignoring broken port multiplier support\n");
                sc->sc_ahci_cap &= ~AHCI_CAP_SPM;
@@ -693,7 +693,7 @@
        switch(ahci_exec_fis(chp, 31, flags)) {
        case ERR_DF:
        case TIMEOUT:
-               if ((sc->sc_achi_quirks & AHCI_QUIRK_BADPMPRESET) != 0 &&
+               if ((sc->sc_ahci_quirks & AHCI_QUIRK_BADPMPRESET) != 0 &&
                    drive == PMP_PORT_CTL) {
                        /*
                         * some controllers fails to reset when
diff -r 0b178cb5d68a -r f3e05bb1956a sys/dev/ic/ahcisatavar.h
--- a/sys/dev/ic/ahcisatavar.h  Mon Aug 20 12:45:36 2012 +0000
+++ b/sys/dev/ic/ahcisatavar.h  Mon Aug 20 12:48:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ahcisatavar.h,v 1.12 2012/08/13 19:42:50 bouyer Exp $  */
+/*     $NetBSD: ahcisatavar.h,v 1.13 2012/08/20 12:48:47 bouyer Exp $  */
 
 /*
  * Copyright (c) 2006 Manuel Bouyer.
@@ -54,7 +54,7 @@
        bus_dma_segment_t sc_cmd_hdr_seg;
        int sc_cmd_hdr_nseg;
        int sc_atac_capflags;
-       int sc_achi_quirks;
+       int sc_ahci_quirks;
 #define AHCI_PCI_QUIRK_FORCE   __BIT(0)  /* force attach */
 #define AHCI_PCI_QUIRK_BAD64   __BIT(1)  /* broken 64-bit DMA */
 #define AHCI_QUIRK_BADPMP      __BIT(2)  /* broken PMP support, ignore */
diff -r 0b178cb5d68a -r f3e05bb1956a sys/dev/pci/ahcisata_pci.c
--- a/sys/dev/pci/ahcisata_pci.c        Mon Aug 20 12:45:36 2012 +0000
+++ b/sys/dev/pci/ahcisata_pci.c        Mon Aug 20 12:48:47 2012 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ahcisata_pci.c,v 1.29 2012/08/10 16:40:40 bouyer Exp $ */
+/*     $NetBSD: ahcisata_pci.c,v 1.30 2012/08/20 12:48:47 bouyer Exp $ */
 
 /*
  * Copyright (c) 2006 Manuel Bouyer.
@@ -26,7 +26,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ahcisata_pci.c,v 1.29 2012/08/10 16:40:40 bouyer Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ahcisata_pci.c,v 1.30 2012/08/20 12:48:47 bouyer Exp $");
 
 #include <sys/types.h>
 #include <sys/malloc.h>
@@ -45,7 +45,7 @@
 struct ahci_pci_quirk { 
        pci_vendor_id_t  vendor;        /* Vendor ID */
        pci_product_id_t product;       /* Product ID */
-       int              quirks;        /* quirks; same as sc_achi_quirks */
+       int              quirks;        /* quirks; same as sc_ahci_quirks */
 };
 
 static const struct ahci_pci_quirk ahci_pci_quirks[] = {
@@ -292,11 +292,11 @@
 
        sc->sc_dmat = pa->pa_dmat;
 
-       sc->sc_achi_quirks = ahci_pci_has_quirk(PCI_VENDOR(pa->pa_id),
+       sc->sc_ahci_quirks = ahci_pci_has_quirk(PCI_VENDOR(pa->pa_id),
                                            PCI_PRODUCT(pa->pa_id));
 
        ahci_cap_64bit = (AHCI_READ(sc, AHCI_CAP) & AHCI_CAP_64BIT) != 0;
-       ahci_bad_64bit = ((sc->sc_achi_quirks & AHCI_PCI_QUIRK_BAD64) != 0);
+       ahci_bad_64bit = ((sc->sc_ahci_quirks & AHCI_PCI_QUIRK_BAD64) != 0);
 
        if (pci_dma64_available(pa) && ahci_cap_64bit) {
                if (!ahci_bad_64bit)



Home | Main Index | Thread Index | Old Index